@@ -16,6 +16,8 @@ from __future__ import annotations
 
 import os
 
+from firefly.application import Container as RootContainer
+
 import boto3
 import firefly_di as di
 
@@ -27,22 +29,28 @@ import firefly_aws.domain as domain
 
 class Container(di.Container):
     # AWS Services
-    s3_client = lambda self: boto3.client('s3')
-    sns_client = lambda self: boto3.client('sns')
     cloudformation_client = lambda self: boto3.client('cloudformation')
+    ddb_client = lambda self: boto3.client('dynamodb')
     lambda_client = lambda self: boto3.client('lambda')
     sns_client = lambda self: boto3.client('sns')
     sqs_client = lambda self: boto3.client('sqs')
+    sqs_resource = lambda self: boto3.resource('sqs')
     rds_data_client = lambda self: boto3.client('rds-data')
-    ddb_client = lambda self: boto3.client('dynamodb')
+    s3_client = lambda self: boto3.client('s3')
+    kinesis_client = lambda self: boto3.client('kinesis')
 
     data_api: infra.DataApi = infra.DataApi
     s3_service: infra.BotoS3Service = infra.BotoS3Service
     lambda_executor: domain.LambdaExecutor = domain.LambdaExecutor
     jwt_decoder: domain.JwtDecoder = infra.CognitoJwtDecoder
     mutex: infra.DdbMutex = infra.DdbMutex
+    rate_limiter: infra.DdbRateLimiter = infra.DdbRateLimiter
+    file_system: ff.FileSystem = infra.S3FileSystem
+    resource_monitor: domain.ResourceMonitor = infra.DdbResourceMonitor
 
 
-if os.environ['ENV'] != 'local':
+if os.environ['FF_ENVIRONMENT'] != 'local':
     Container.message_transport = infra.BotoMessageTransport
     Container.__annotations__['message_transport'] = ff.MessageTransport
+
+del RootContainer.file_system
