@@ -12,4 +12,4 @@
 #  You should have received a copy of the GNU General Public License along with Firefly. If not, see
 #  <http://www.gnu.org/licenses/>.
 
-from .aws_agent import AwsAgent
+from .update_resource_settings import UpdateResourceSettings
